<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ArcConcentricThrough</name>
    <message>
        <location filename="../ArcConcentricThrough.ui" line="+17"/>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation>Liczba kopii:</translation>
    </message>
    <message>
        <location filename="../ArcConcentricThroughInit.js" line="+2"/>
        <source>Concentric (&amp;through Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Koncentryczny (p&amp;rzez punkt)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw concentric arc through point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje koncentryczny łuk przez punkt</translation>
    </message>
</context>
</TS>
